package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TCutOffWater;
import com.slibra.business.service.ITCutOffWaterService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 停水信息Controller
 * 
 * @author slibra
 * @date 2024-11-05
 */
@RestController
@RequestMapping("/business/water")
public class TCutOffWaterController extends BaseController
{
    @Autowired
    private ITCutOffWaterService tCutOffWaterService;

    /**
     * 查询停水信息列表
     */
    @PreAuthorize("@ss.hasPermi('business:water:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCutOffWater tCutOffWater)
    {
        startPage();
        List<TCutOffWater> list = tCutOffWaterService.selectTCutOffWaterList(tCutOffWater);
        return getDataTable(list);
    }

    /**
     * 导出停水信息列表
     */
    @PreAuthorize("@ss.hasPermi('business:water:export')")
    @Log(title = "停水信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCutOffWater tCutOffWater)
    {
        List<TCutOffWater> list = tCutOffWaterService.selectTCutOffWaterList(tCutOffWater);
        ExcelUtil<TCutOffWater> util = new ExcelUtil<TCutOffWater>(TCutOffWater.class);
        util.exportExcel(response, list, "停水信息数据");
    }

    /**
     * 获取停水信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:water:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tCutOffWaterService.selectTCutOffWaterById(id));
    }

    /**
     * 新增停水信息
     */
    @PreAuthorize("@ss.hasPermi('business:water:add')")
    @Log(title = "停水信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCutOffWater tCutOffWater)
    {
        tCutOffWater.setCreateBy(getUsername());
        return toAjax(tCutOffWaterService.insertTCutOffWater(tCutOffWater));
    }

    /**
     * 修改停水信息
     */
    @PreAuthorize("@ss.hasPermi('business:water:edit')")
    @Log(title = "停水信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCutOffWater tCutOffWater)
    {
        tCutOffWater.setUpdateBy(getUsername());
        return toAjax(tCutOffWaterService.updateTCutOffWater(tCutOffWater));
    }

    /**
     * 删除停水信息
     */
    @PreAuthorize("@ss.hasPermi('business:water:remove')")
    @Log(title = "停水信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tCutOffWaterService.deleteTCutOffWaterByIds(ids));
    }
}
