package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TPumpingStation;
import com.slibra.business.service.ITPumpingStationService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 泵站Controller
 * 
 * @author slibra
 * @date 2024-11-05
 */
@RestController
@RequestMapping("/business/station")
public class TPumpingStationController extends BaseController
{
    @Autowired
    private ITPumpingStationService tPumpingStationService;

    /**
     * 查询泵站列表
     */
    @PreAuthorize("@ss.hasPermi('business:station:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPumpingStation tPumpingStation)
    {
        startPage();
        List<TPumpingStation> list = tPumpingStationService.selectTPumpingStationList(tPumpingStation);
        return getDataTable(list);
    }

    /**
     * 导出泵站列表
     */
    @PreAuthorize("@ss.hasPermi('business:station:export')")
    @Log(title = "泵站", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPumpingStation tPumpingStation)
    {
        List<TPumpingStation> list = tPumpingStationService.selectTPumpingStationList(tPumpingStation);
        ExcelUtil<TPumpingStation> util = new ExcelUtil<TPumpingStation>(TPumpingStation.class);
        util.exportExcel(response, list, "泵站数据");
    }

    /**
     * 获取泵站详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:station:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tPumpingStationService.selectTPumpingStationById(id));
    }

    /**
     * 新增泵站
     */
    @PreAuthorize("@ss.hasPermi('business:station:add')")
    @Log(title = "泵站", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPumpingStation tPumpingStation)
    {
        tPumpingStation.setCreateBy(getUsername());
        return toAjax(tPumpingStationService.insertTPumpingStation(tPumpingStation));
    }

    /**
     * 修改泵站
     */
    @PreAuthorize("@ss.hasPermi('business:station:edit')")
    @Log(title = "泵站", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPumpingStation tPumpingStation)
    {
        tPumpingStation.setUpdateBy(getUsername());
        return toAjax(tPumpingStationService.updateTPumpingStation(tPumpingStation));
    }

    /**
     * 删除泵站
     */
    @PreAuthorize("@ss.hasPermi('business:station:remove')")
    @Log(title = "泵站", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tPumpingStationService.deleteTPumpingStationByIds(ids));
    }
}
