package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TPumpingStationNeighbourhoodNumber;
import com.slibra.business.service.ITPumpingStationNeighbourhoodNumberService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 泵站-小区楼号中间Controller
 * 
 * @author slibra
 * @date 2024-11-05
 */
@RestController
@RequestMapping("/business/number")
public class TPumpingStationNeighbourhoodNumberController extends BaseController
{
    @Autowired
    private ITPumpingStationNeighbourhoodNumberService tPumpingStationNeighbourhoodNumberService;

    /**
     * 查询泵站-小区楼号中间列表
     */
    @PreAuthorize("@ss.hasPermi('business:number:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPumpingStationNeighbourhoodNumber tPumpingStationNeighbourhoodNumber)
    {
        startPage();
        List<TPumpingStationNeighbourhoodNumber> list = tPumpingStationNeighbourhoodNumberService.selectTPumpingStationNeighbourhoodNumberList(tPumpingStationNeighbourhoodNumber);
        return getDataTable(list);
    }

    /**
     * 导出泵站-小区楼号中间列表
     */
    @PreAuthorize("@ss.hasPermi('business:number:export')")
    @Log(title = "泵站-小区楼号中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPumpingStationNeighbourhoodNumber tPumpingStationNeighbourhoodNumber)
    {
        List<TPumpingStationNeighbourhoodNumber> list = tPumpingStationNeighbourhoodNumberService.selectTPumpingStationNeighbourhoodNumberList(tPumpingStationNeighbourhoodNumber);
        ExcelUtil<TPumpingStationNeighbourhoodNumber> util = new ExcelUtil<TPumpingStationNeighbourhoodNumber>(TPumpingStationNeighbourhoodNumber.class);
        util.exportExcel(response, list, "泵站-小区楼号中间数据");
    }

    /**
     * 获取泵站-小区楼号中间详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:number:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tPumpingStationNeighbourhoodNumberService.selectTPumpingStationNeighbourhoodNumberById(id));
    }

    /**
     * 新增泵站-小区楼号中间
     */
    @PreAuthorize("@ss.hasPermi('business:number:add')")
    @Log(title = "泵站-小区楼号中间", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPumpingStationNeighbourhoodNumber tPumpingStationNeighbourhoodNumber)
    {
        tPumpingStationNeighbourhoodNumber.setCreateBy(getUsername());
        return toAjax(tPumpingStationNeighbourhoodNumberService.insertTPumpingStationNeighbourhoodNumber(tPumpingStationNeighbourhoodNumber));
    }

    /**
     * 修改泵站-小区楼号中间
     */
    @PreAuthorize("@ss.hasPermi('business:number:edit')")
    @Log(title = "泵站-小区楼号中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPumpingStationNeighbourhoodNumber tPumpingStationNeighbourhoodNumber)
    {
        tPumpingStationNeighbourhoodNumber.setUpdateBy(getUsername());
        return toAjax(tPumpingStationNeighbourhoodNumberService.updateTPumpingStationNeighbourhoodNumber(tPumpingStationNeighbourhoodNumber));
    }

    /**
     * 删除泵站-小区楼号中间
     */
    @PreAuthorize("@ss.hasPermi('business:number:remove')")
    @Log(title = "泵站-小区楼号中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tPumpingStationNeighbourhoodNumberService.deleteTPumpingStationNeighbourhoodNumberByIds(ids));
    }
}
