package com.slibra.common.utils.bean;

import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;

/**
 * 智能投药参数设置对象 t_xinyi_medicine_param
 * 
 * @author slibra
 * @date 2024-09-09
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class TXinyiMedicineParam extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 加药泵（0 1号泵 ；1 2号泵 ；2 3号泵） */
    @Excel(name = "加药泵", readConverterExp = "0=,1=号泵,；=1,2=号泵,；=2,3=号泵")
    private Long numberBeng;

    /** 加药方式(0自动 1一号池 2二号池 3人工投放) */
    @Excel(name = "加药方式(0自动 1一号池 2二号池 3人工投放)")
    private Integer type;

    /** 进水流量类型（0手动 1仪表） */
    @Excel(name = "进水流量类型", readConverterExp = "0=手动,1=仪表")
    private Integer jsLlType;

    /** 进水流量1号池 */
    @Excel(name = "进水流量1号池")
    private BigDecimal jsLlOne;

    /** 进水流量2号池 */
    @Excel(name = "进水流量2号池")
    private BigDecimal jsLlTwo;

    /** 进水cod类型（0手动 1仪表 2化验） */
    @Excel(name = "进水cod类型", readConverterExp = "0=手动,1=仪表,2=化验")
    private Integer jsCodType;

    /** 进水cod1号池 */
    @Excel(name = "进水cod1号池")
    private BigDecimal jsCodOne;

    /** 进水cod二号池 */
    @Excel(name = "进水cod二号池")
    private BigDecimal jsCodTwo;

    /** 好氧池硝酸盐类型（0手动 1化验 2预测） */
    @Excel(name = "好氧池硝酸盐类型", readConverterExp = "0=手动,1=化验,2=预测")
    private Integer hycXsyType;

    /** 好氧池硝酸盐1号池 */
    @Excel(name = "好氧池硝酸盐1号池")
    private BigDecimal hycXsyOne;

    /** 好氧池硝酸盐二号池 */
    @Excel(name = "好氧池硝酸盐二号池")
    private BigDecimal hycXsyTwo;

    /** 缺氧池硝酸盐类型（0手动 1化验） */
    @Excel(name = "缺氧池硝酸盐类型", readConverterExp = "0=手动,1=化验")
    private Integer qycYxyType;

    /** 缺氧池硝酸盐1号池 */
    @Excel(name = "缺氧池硝酸盐1号池")
    private BigDecimal qycYxyOne;

    /** 缺氧池硝酸盐2号池 */
    @Excel(name = "缺氧池硝酸盐2号池")
    private BigDecimal qycYxyTwo;

    /** 缺氧池氨氮类型（0手动 1化验） */
    @Excel(name = "缺氧池氨氮类型", readConverterExp = "0=手动,1=化验")
    private Integer qycAdType;

    /** 缺氧池氨氮1号池 */
    @Excel(name = "缺氧池氨氮1号池")
    private BigDecimal qycAdOne;

    /** 缺氧池氨氮二号池 */
    @Excel(name = "缺氧池氨氮二号池")
    private BigDecimal qycAdTwo;

    /** 进水总氮类型（0手动 1仪表） */
    @Excel(name = "进水总氮类型", readConverterExp = "0=手动,1=仪表")
    private Integer jsTnType;

    /** 进水总氮1号池 */
    @Excel(name = "进水总氮1号池")
    private BigDecimal jsTnOne;

    /** 进水总氮2号池 */
    @Excel(name = "进水总氮2号池")
    private BigDecimal jsTnTwo;

    /** 后台反馈设定 */
    @Excel(name = "后台反馈设定")
    private BigDecimal htfksd;

    /** 基准系数 */
    @Excel(name = "基准系数")
    private BigDecimal jzxs;

    /** 修正系数 */
    @Excel(name = "修正系数")
    private BigDecimal xzxs;

    /** 控制系数 */
    @Excel(name = "控制系数")
    private BigDecimal kzxs;

    /** 水量分配系数 */
    @Excel(name = "水量分配系数")
    private BigDecimal slfpxs;

    /** 碳源当量 */
    @Excel(name = "碳源当量")
    private BigDecimal tydl;

    /** 转换系数 */
    @Excel(name = "转换系数")
    private BigDecimal zhxs;

    /** 稀释配属 */
    @Excel(name = "稀释配属")
    private BigDecimal sxps;

    /** 药剂密度 */
    @Excel(name = "药剂密度")
    private BigDecimal yymd;

    /** 最小启动流量 */
    @Excel(name = "最小启动流量")
    private BigDecimal zxqdll;

    /** 碳氮比 */
    @Excel(name = "碳氮比")
    private BigDecimal tdb;

    /** 加药量 */
    @Excel(name = "加药量")
    private BigDecimal medicineAmount;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;

    //额外查询的字段
    //碳源投加瞬时流量
    private BigDecimal tytjTransientLL;

    //投加运行方式(0启用智适应碳源投加  1手动碳源投加)
    private Integer addType;

    //请求参数

    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;
}
