package com.slibra.framework.web.service;

import com.slibra.system.mapper.SysPostMapper;
import com.slibra.system.mapper.SysUserPostMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;
import com.slibra.common.core.domain.entity.SysUser;
import com.slibra.common.core.domain.model.LoginUser;
import com.slibra.common.enums.UserStatus;
import com.slibra.common.exception.ServiceException;
import com.slibra.common.utils.MessageUtils;
import com.slibra.common.utils.StringUtils;
import com.slibra.system.service.ISysUserService;

import static com.slibra.common.constant.MyConstants.LOGIN_TYPE_APPEND;

/**
 * 用户验证处理
 *
 *
 */
@Service("userDetailsByUsername")
public class UserDetailsServiceImpl implements UserDetailsService
{
    private static final Logger log = LoggerFactory.getLogger(UserDetailsServiceImpl.class);

    @Autowired
    private ISysUserService userService;
    
    @Autowired
    private SysPasswordService passwordService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private SysPostMapper sysPostMapper;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException
    {
        SysUser user = userService.selectUserByUserName(username);
        if (StringUtils.isNull(user))
        {
            log.info("登录用户：{} 不存在.", username.split(LOGIN_TYPE_APPEND)[0]);
            throw new ServiceException("登录用户：" + username.split(LOGIN_TYPE_APPEND)[0]+ " 不存在");
        }
        else if (UserStatus.DELETED.getCode().equals(user.getDelFlag()))
        {
            log.info("登录用户：{} 已被删除.", username);
            throw new ServiceException(MessageUtils.message("user.password.delete"));
        }
        else if (UserStatus.DISABLE.getCode().equals(user.getStatus()))
        {
            log.info("登录用户：{} 已被停用.", username);
            throw new ServiceException(MessageUtils.message("user.blocked"));
        }
        //2024年08月16日10:21:30  额外再处理一下用户的职位信息（前端接口使用）
        /*Long[] postIds = user.getPostIds();
        if (StringUtils.isNotEmpty(postIds)){
            user.setPosition(this.sysPostMapper.getPostNamesByIds(postIds));
        }*/
        user.setPosition(this.sysPostMapper.getPostNamesByUserId(user.getUserId()));

        passwordService.validate(user);

        return createLoginUser(user);
    }

    public UserDetails createLoginUser(SysUser user)
    {
        return new LoginUser(user.getUserId(), user.getDeptId(), user, permissionService.getMenuPermission(user));
    }
}
