package com.slibra.business.domain;

import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 用户水费明细对象 t_user_fee_info
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TUserFeeInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 用户ID */
    @Excel(name = "用户ID")
    private String userId;

    /** 本次统计时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "本次统计时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date statisticsTime;

    /** 账户余额 */
    @Excel(name = "账户余额")
    private BigDecimal balanceFees;

    /** 未扣费总额 */
    @Excel(name = "未扣费总额")
    private BigDecimal unpaidFees;

    /** 水费 */
    @Excel(name = "水费")
    private BigDecimal waterFees;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;

    public void setId(Long id) 
    {
        this.id = id;
    }

    public Long getId() 
    {
        return id;
    }
    public void setUserId(String userId) 
    {
        this.userId = userId;
    }

    public String getUserId() 
    {
        return userId;
    }
    public void setStatisticsTime(Date statisticsTime) 
    {
        this.statisticsTime = statisticsTime;
    }

    public Date getStatisticsTime() 
    {
        return statisticsTime;
    }
    public void setBalanceFees(BigDecimal balanceFees) 
    {
        this.balanceFees = balanceFees;
    }

    public BigDecimal getBalanceFees() 
    {
        return balanceFees;
    }
    public void setUnpaidFees(BigDecimal unpaidFees) 
    {
        this.unpaidFees = unpaidFees;
    }

    public BigDecimal getUnpaidFees() 
    {
        return unpaidFees;
    }
    public void setWaterFees(BigDecimal waterFees) 
    {
        this.waterFees = waterFees;
    }

    public BigDecimal getWaterFees() 
    {
        return waterFees;
    }
    public void setDelFlag(Long delFlag) 
    {
        this.delFlag = delFlag;
    }

    public Long getDelFlag() 
    {
        return delFlag;
    }
    public void setRevision(Long revision) 
    {
        this.revision = revision;
    }

    public Long getRevision() 
    {
        return revision;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("userId", getUserId())
            .append("statisticsTime", getStatisticsTime())
            .append("balanceFees", getBalanceFees())
            .append("unpaidFees", getUnpaidFees())
            .append("waterFees", getWaterFees())
            .append("delFlag", getDelFlag())
            .append("revision", getRevision())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .append("remark", getRemark())
            .toString();
    }
}
