package com.slibra.business.domain;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 用户信息对象 t_user_info
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TUserInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 户号 */
    @Excel(name = "户号")
    private String cardNo;

    /** 用户编号 */
    @Excel(name = "用户编号")
    private String userNo;

    /** 用户名称 */
    @Excel(name = "用户名称")
    private String name;

    /** 移动电话（来电号码） */
    @Excel(name = "移动电话", readConverterExp = "来=电号码")
    private String phone;

    /** 省 */
    @Excel(name = "省")
    private String province;

    /** 市 */
    @Excel(name = "市")
    private String city;

    /** 区县 */
    @Excel(name = "区县")
    private String country;

    /** 街道 */
    @Excel(name = "街道")
    private String street;

    /** 小区名称 */
    @Excel(name = "小区名称")
    private String address;

    /** 楼号 */
    @Excel(name = "楼号")
    private String buildingNo;

    /** 门牌号 */
    @Excel(name = "门牌号")
    private String doorNo;

    /** 表身号 */
    @Excel(name = "表身号")
    private String ammeterNo;

    /** 泵站名称 */
    @Excel(name = "泵站名称")
    private String pumpingStation;

    /** 抄表员名称 */
    @Excel(name = "抄表员名称")
    private String meterReader;

    /** 抄表员电话 */
    @Excel(name = "抄表员电话")
    private String meterReaderPhone;

    /** 删除标志（0代表存在 2代表删除） */
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    private Long revision;

    public void setId(Long id) 
    {
        this.id = id;
    }

    public Long getId() 
    {
        return id;
    }
    public void setCardNo(String cardNo) 
    {
        this.cardNo = cardNo;
    }

    public String getCardNo() 
    {
        return cardNo;
    }
    public void setUserNo(String userNo) 
    {
        this.userNo = userNo;
    }

    public String getUserNo() 
    {
        return userNo;
    }
    public void setName(String name) 
    {
        this.name = name;
    }

    public String getName() 
    {
        return name;
    }
    public void setPhone(String phone) 
    {
        this.phone = phone;
    }

    public String getPhone() 
    {
        return phone;
    }
    public void setProvince(String province) 
    {
        this.province = province;
    }

    public String getProvince() 
    {
        return province;
    }
    public void setCity(String city) 
    {
        this.city = city;
    }

    public String getCity() 
    {
        return city;
    }
    public void setCountry(String country) 
    {
        this.country = country;
    }

    public String getCountry() 
    {
        return country;
    }
    public void setStreet(String street) 
    {
        this.street = street;
    }

    public String getStreet() 
    {
        return street;
    }
    public void setAddress(String address) 
    {
        this.address = address;
    }

    public String getAddress() 
    {
        return address;
    }
    public void setBuildingNo(String buildingNo) 
    {
        this.buildingNo = buildingNo;
    }

    public String getBuildingNo() 
    {
        return buildingNo;
    }
    public void setDoorNo(String doorNo) 
    {
        this.doorNo = doorNo;
    }

    public String getDoorNo() 
    {
        return doorNo;
    }
    public void setAmmeterNo(String ammeterNo) 
    {
        this.ammeterNo = ammeterNo;
    }

    public String getAmmeterNo() 
    {
        return ammeterNo;
    }
    public void setPumpingStation(String pumpingStation) 
    {
        this.pumpingStation = pumpingStation;
    }

    public String getPumpingStation() 
    {
        return pumpingStation;
    }
    public void setMeterReader(String meterReader) 
    {
        this.meterReader = meterReader;
    }

    public String getMeterReader() 
    {
        return meterReader;
    }
    public void setMeterReaderPhone(String meterReaderPhone) 
    {
        this.meterReaderPhone = meterReaderPhone;
    }

    public String getMeterReaderPhone() 
    {
        return meterReaderPhone;
    }
    public void setDelFlag(Long delFlag) 
    {
        this.delFlag = delFlag;
    }

    public Long getDelFlag() 
    {
        return delFlag;
    }
    public void setRevision(Long revision) 
    {
        this.revision = revision;
    }

    public Long getRevision() 
    {
        return revision;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("cardNo", getCardNo())
            .append("userNo", getUserNo())
            .append("name", getName())
            .append("phone", getPhone())
            .append("province", getProvince())
            .append("city", getCity())
            .append("country", getCountry())
            .append("street", getStreet())
            .append("address", getAddress())
            .append("buildingNo", getBuildingNo())
            .append("doorNo", getDoorNo())
            .append("ammeterNo", getAmmeterNo())
            .append("pumpingStation", getPumpingStation())
            .append("meterReader", getMeterReader())
            .append("meterReaderPhone", getMeterReaderPhone())
            .append("delFlag", getDelFlag())
            .append("revision", getRevision())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .append("remark", getRemark())
            .toString();
    }
}
