package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TCutOffWaterMapper;
import com.slibra.business.domain.TCutOffWater;
import com.slibra.business.service.ITCutOffWaterService;

/**
 * 停水信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Service
public class TCutOffWaterServiceImpl implements ITCutOffWaterService 
{
    @Autowired
    private TCutOffWaterMapper tCutOffWaterMapper;

    /**
     * 查询停水信息
     * 
     * @param id 停水信息主键
     * @return 停水信息
     */
    @Override
    public TCutOffWater selectTCutOffWaterById(Long id)
    {
        return tCutOffWaterMapper.selectTCutOffWaterById(id);
    }

    /**
     * 查询停水信息列表
     * 
     * @param tCutOffWater 停水信息
     * @return 停水信息
     */
    @Override
    public List<TCutOffWater> selectTCutOffWaterList(TCutOffWater tCutOffWater)
    {
        return tCutOffWaterMapper.selectTCutOffWaterList(tCutOffWater);
    }

    /**
     * 新增停水信息
     * 
     * @param tCutOffWater 停水信息
     * @return 结果
     */
    @Override
    public int insertTCutOffWater(TCutOffWater tCutOffWater)
    {
        tCutOffWater.setCreateTime(DateUtils.getNowDate());
        return tCutOffWaterMapper.insertTCutOffWater(tCutOffWater);
    }

    /**
     * 修改停水信息
     * 
     * @param tCutOffWater 停水信息
     * @return 结果
     */
    @Override
    public int updateTCutOffWater(TCutOffWater tCutOffWater)
    {
        tCutOffWater.setUpdateTime(DateUtils.getNowDate());
        return tCutOffWaterMapper.updateTCutOffWater(tCutOffWater);
    }

    /**
     * 批量删除停水信息
     * 
     * @param ids 需要删除的停水信息主键
     * @return 结果
     */
    @Override
    public int deleteTCutOffWaterByIds(Long[] ids)
    {
        return tCutOffWaterMapper.deleteTCutOffWaterByIds(ids);
    }

    /**
     * 删除停水信息信息
     * 
     * @param id 停水信息主键
     * @return 结果
     */
    @Override
    public int deleteTCutOffWaterById(Long id)
    {
        return tCutOffWaterMapper.deleteTCutOffWaterById(id);
    }
}
