package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TNeighborhoodBuildingMapper;
import com.slibra.business.domain.TNeighborhoodBuilding;
import com.slibra.business.service.ITNeighborhoodBuildingService;

/**
 * 楼号信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Service
public class TNeighborhoodBuildingServiceImpl implements ITNeighborhoodBuildingService 
{
    @Autowired
    private TNeighborhoodBuildingMapper tNeighborhoodBuildingMapper;

    /**
     * 查询楼号信息
     * 
     * @param id 楼号信息主键
     * @return 楼号信息
     */
    @Override
    public TNeighborhoodBuilding selectTNeighborhoodBuildingById(Long id)
    {
        return tNeighborhoodBuildingMapper.selectTNeighborhoodBuildingById(id);
    }

    /**
     * 查询楼号信息列表
     * 
     * @param tNeighborhoodBuilding 楼号信息
     * @return 楼号信息
     */
    @Override
    public List<TNeighborhoodBuilding> selectTNeighborhoodBuildingList(TNeighborhoodBuilding tNeighborhoodBuilding)
    {
        return tNeighborhoodBuildingMapper.selectTNeighborhoodBuildingList(tNeighborhoodBuilding);
    }

    /**
     * 新增楼号信息
     * 
     * @param tNeighborhoodBuilding 楼号信息
     * @return 结果
     */
    @Override
    public int insertTNeighborhoodBuilding(TNeighborhoodBuilding tNeighborhoodBuilding)
    {
        tNeighborhoodBuilding.setCreateTime(DateUtils.getNowDate());
        return tNeighborhoodBuildingMapper.insertTNeighborhoodBuilding(tNeighborhoodBuilding);
    }

    /**
     * 修改楼号信息
     * 
     * @param tNeighborhoodBuilding 楼号信息
     * @return 结果
     */
    @Override
    public int updateTNeighborhoodBuilding(TNeighborhoodBuilding tNeighborhoodBuilding)
    {
        tNeighborhoodBuilding.setUpdateTime(DateUtils.getNowDate());
        return tNeighborhoodBuildingMapper.updateTNeighborhoodBuilding(tNeighborhoodBuilding);
    }

    /**
     * 批量删除楼号信息
     * 
     * @param ids 需要删除的楼号信息主键
     * @return 结果
     */
    @Override
    public int deleteTNeighborhoodBuildingByIds(Long[] ids)
    {
        return tNeighborhoodBuildingMapper.deleteTNeighborhoodBuildingByIds(ids);
    }

    /**
     * 删除楼号信息信息
     * 
     * @param id 楼号信息主键
     * @return 结果
     */
    @Override
    public int deleteTNeighborhoodBuildingById(Long id)
    {
        return tNeighborhoodBuildingMapper.deleteTNeighborhoodBuildingById(id);
    }
}
