package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TNeighborhoodMapper;
import com.slibra.business.domain.TNeighborhood;
import com.slibra.business.service.ITNeighborhoodService;

/**
 * 服务小区Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Service
public class TNeighborhoodServiceImpl implements ITNeighborhoodService 
{
    @Autowired
    private TNeighborhoodMapper tNeighborhoodMapper;

    /**
     * 查询服务小区
     * 
     * @param id 服务小区主键
     * @return 服务小区
     */
    @Override
    public TNeighborhood selectTNeighborhoodById(Long id)
    {
        return tNeighborhoodMapper.selectTNeighborhoodById(id);
    }

    /**
     * 查询服务小区列表
     * 
     * @param tNeighborhood 服务小区
     * @return 服务小区
     */
    @Override
    public List<TNeighborhood> selectTNeighborhoodList(TNeighborhood tNeighborhood)
    {
        return tNeighborhoodMapper.selectTNeighborhoodList(tNeighborhood);
    }

    /**
     * 新增服务小区
     * 
     * @param tNeighborhood 服务小区
     * @return 结果
     */
    @Override
    public int insertTNeighborhood(TNeighborhood tNeighborhood)
    {
        tNeighborhood.setCreateTime(DateUtils.getNowDate());
        return tNeighborhoodMapper.insertTNeighborhood(tNeighborhood);
    }

    /**
     * 修改服务小区
     * 
     * @param tNeighborhood 服务小区
     * @return 结果
     */
    @Override
    public int updateTNeighborhood(TNeighborhood tNeighborhood)
    {
        tNeighborhood.setUpdateTime(DateUtils.getNowDate());
        return tNeighborhoodMapper.updateTNeighborhood(tNeighborhood);
    }

    /**
     * 批量删除服务小区
     * 
     * @param ids 需要删除的服务小区主键
     * @return 结果
     */
    @Override
    public int deleteTNeighborhoodByIds(Long[] ids)
    {
        return tNeighborhoodMapper.deleteTNeighborhoodByIds(ids);
    }

    /**
     * 删除服务小区信息
     * 
     * @param id 服务小区主键
     * @return 结果
     */
    @Override
    public int deleteTNeighborhoodById(Long id)
    {
        return tNeighborhoodMapper.deleteTNeighborhoodById(id);
    }
}
