package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TPumpingStationMapper;
import com.slibra.business.domain.TPumpingStation;
import com.slibra.business.service.ITPumpingStationService;

/**
 * 泵站Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Service
public class TPumpingStationServiceImpl implements ITPumpingStationService 
{
    @Autowired
    private TPumpingStationMapper tPumpingStationMapper;

    /**
     * 查询泵站
     * 
     * @param id 泵站主键
     * @return 泵站
     */
    @Override
    public TPumpingStation selectTPumpingStationById(Long id)
    {
        return tPumpingStationMapper.selectTPumpingStationById(id);
    }

    /**
     * 查询泵站列表
     * 
     * @param tPumpingStation 泵站
     * @return 泵站
     */
    @Override
    public List<TPumpingStation> selectTPumpingStationList(TPumpingStation tPumpingStation)
    {
        return tPumpingStationMapper.selectTPumpingStationList(tPumpingStation);
    }

    /**
     * 新增泵站
     * 
     * @param tPumpingStation 泵站
     * @return 结果
     */
    @Override
    public int insertTPumpingStation(TPumpingStation tPumpingStation)
    {
        tPumpingStation.setCreateTime(DateUtils.getNowDate());
        return tPumpingStationMapper.insertTPumpingStation(tPumpingStation);
    }

    /**
     * 修改泵站
     * 
     * @param tPumpingStation 泵站
     * @return 结果
     */
    @Override
    public int updateTPumpingStation(TPumpingStation tPumpingStation)
    {
        tPumpingStation.setUpdateTime(DateUtils.getNowDate());
        return tPumpingStationMapper.updateTPumpingStation(tPumpingStation);
    }

    /**
     * 批量删除泵站
     * 
     * @param ids 需要删除的泵站主键
     * @return 结果
     */
    @Override
    public int deleteTPumpingStationByIds(Long[] ids)
    {
        return tPumpingStationMapper.deleteTPumpingStationByIds(ids);
    }

    /**
     * 删除泵站信息
     * 
     * @param id 泵站主键
     * @return 结果
     */
    @Override
    public int deleteTPumpingStationById(Long id)
    {
        return tPumpingStationMapper.deleteTPumpingStationById(id);
    }
}
